==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/MDMEnrollmentPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.MDMEnrollmentPolicyEnrollment;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * MDMEnrollmentPolicyRuleCondition
 */
@JsonPropertyOrder({ MDMEnrollmentPolicyRuleCondition.JSON_PROPERTY_BLOCK_NON_SAFE_ANDROID,
        MDMEnrollmentPolicyRuleCondition.JSON_PROPERTY_ENROLLMENT })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class MDMEnrollmentPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BLOCK_NON_SAFE_ANDROID = "blockNonSafeAndroid";
    private Boolean blockNonSafeAndroid;

    public static final String JSON_PROPERTY_ENROLLMENT = "enrollment";
    private MDMEnrollmentPolicyEnrollment enrollment;

    public MDMEnrollmentPolicyRuleCondition() {
    }

    public MDMEnrollmentPolicyRuleCondition blockNonSafeAndroid(Boolean blockNonSafeAndroid) {

        this.blockNonSafeAndroid = blockNonSafeAndroid;
        return this;
    }

    /**
     * Get blockNonSafeAndroid
     *
     * @return blockNonSafeAndroid
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_BLOCK_NON_SAFE_ANDROID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getBlockNonSafeAndroid() {
        return blockNonSafeAndroid;
    }

    @JsonProperty(JSON_PROPERTY_BLOCK_NON_SAFE_ANDROID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBlockNonSafeAndroid(Boolean blockNonSafeAndroid) {
        this.blockNonSafeAndroid = blockNonSafeAndroid;
    }

    public MDMEnrollmentPolicyRuleCondition enrollment(MDMEnrollmentPolicyEnrollment enrollment) {

        this.enrollment = enrollment;
        return this;
    }

    /**
     * Get enrollment
     *
     * @return enrollment
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENROLLMENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public MDMEnrollmentPolicyEnrollment getEnrollment() {
        return enrollment;
    }

    @JsonProperty(JSON_PROPERTY_ENROLLMENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEnrollment(MDMEnrollmentPolicyEnrollment enrollment) {
        this.enrollment = enrollment;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        MDMEnrollmentPolicyRuleCondition mdMEnrollmentPolicyRuleCondition = (MDMEnrollmentPolicyRuleCondition) o;
        return Objects.equals(this.blockNonSafeAndroid, mdMEnrollmentPolicyRuleCondition.blockNonSafeAndroid)
                && Objects.equals(this.enrollment, mdMEnrollmentPolicyRuleCondition.enrollment);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(blockNonSafeAndroid, enrollment);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class MDMEnrollmentPolicyRuleCondition {\n");
        sb.append("    blockNonSafeAndroid: ").append(toIndentedString(blockNonSafeAndroid)).append("\n");
        sb.append("    enrollment: ").append(toIndentedString(enrollment)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/MDMEnrollmentPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.MDMEnrollmentPolicyEnrollment;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * MDMEnrollmentPolicyRuleCondition
 */
@JsonPropertyOrder({ MDMEnrollmentPolicyRuleCondition.JSON_PROPERTY_BLOCK_NON_SAFE_ANDROID,
        MDMEnrollmentPolicyRuleCondition.JSON_PROPERTY_ENROLLMENT })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class MDMEnrollmentPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BLOCK_NON_SAFE_ANDROID = "blockNonSafeAndroid";
    private Boolean blockNonSafeAndroid;

    public static final String JSON_PROPERTY_ENROLLMENT = "enrollment";
    private MDMEnrollmentPolicyEnrollment enrollment;

    public MDMEnrollmentPolicyRuleCondition() {
    }

    public MDMEnrollmentPolicyRuleCondition blockNonSafeAndroid(Boolean blockNonSafeAndroid) {

        this.blockNonSafeAndroid = blockNonSafeAndroid;
        return this;
    }

    /**
     * Get blockNonSafeAndroid
     *
     * @return blockNonSafeAndroid
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_BLOCK_NON_SAFE_ANDROID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getBlockNonSafeAndroid() {
        return blockNonSafeAndroid;
    }

    @JsonProperty(JSON_PROPERTY_BLOCK_NON_SAFE_ANDROID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBlockNonSafeAndroid(Boolean blockNonSafeAndroid) {
        this.blockNonSafeAndroid = blockNonSafeAndroid;
    }

    public MDMEnrollmentPolicyRuleCondition enrollment(MDMEnrollmentPolicyEnrollment enrollment) {

        this.enrollment = enrollment;
        return this;
    }

    /**
     * Get enrollment
     *
     * @return enrollment
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENROLLMENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public MDMEnrollmentPolicyEnrollment getEnrollment() {
        return enrollment;
    }

    @JsonProperty(JSON_PROPERTY_ENROLLMENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEnrollment(MDMEnrollmentPolicyEnrollment enrollment) {
        this.enrollment = enrollment;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        MDMEnrollmentPolicyRuleCondition mdMEnrollmentPolicyRuleCondition = (MDMEnrollmentPolicyRuleCondition) o;
        return Objects.equals(this.blockNonSafeAndroid, mdMEnrollmentPolicyRuleCondition.blockNonSafeAndroid)
                && Objects.equals(this.enrollment, mdMEnrollmentPolicyRuleCondition.enrollment);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(blockNonSafeAndroid, enrollment);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class MDMEnrollmentPolicyRuleCondition {\n");
        sb.append("    blockNonSafeAndroid: ").append(toIndentedString(blockNonSafeAndroid)).append("\n");
        sb.append("    enrollment: ").append(toIndentedString(enrollment)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
